The NITF image header (sarpy.io.general.nitf_elements.image)
============================================================

.. automodule:: sarpy.io.general.nitf_elements.image
    :members:
    :show-inheritance:
    :inherited-members:
